#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Aug 24 13:55:47 2020

@author: refael

This is an example of streaming depth data from a KeaC camera and displaying
the data in real-time using Matplotlib imshow
"""

import matplotlib.pyplot as plt

import chronoptics.tof as tof
import numpy as np


def handle_close(evt):
    cam.disconnect()
    return


serial = "2020004"

cam = tof.GigeInterface()
cam.connect(cam.find(serial))

config = cam.downloadConfiguration()
config.reset()

config.setBinning(0, 1)
config.setModulationFrequency(0, 50)
config.setFlip(0, True)

proc = tof.ProcessingConfig()

proc.setCalibrationEnabled(True)

proc.setTemporalEnabled(True)
proc.setTemporalNframes(25)
proc.setTemporalSigma(3.0)

proc.setCharMult(0.6)
proc.setCharAdd(0.3)

# Connect, and check depth streaming is supported on the camera
config.setProcessing(proc)

cam.uploadConfiguration(config)

# Start the camera
stream = tof.DepthStreamType.RADIAL

if not cam.depthStreamCapable(stream):
    raise RuntimeError(
        "Connected ToF Camera does not support on board depth calculation"
    )

# Display the radial and intensity
if not cam.testStreamPacketSize():
    raise RuntimeError("Looks like network is too slow to run camera!")

cam.startDepthStream(stream)

fig = plt.figure()
fig.canvas.mpl_connect("close_event", handle_close)

roi = config.getRoi(0)
nrows = roi.getImgRows()
ncols = roi.getImgCols()

plt.subplot(111)
rimg = plt.imshow(
    np.zeros((nrows, ncols), dtype=np.uint16),
    cmap="jet",
    vmin=0,
    vmax=2**16,
    interpolation="none",
)
plt.title("Radial")


while cam.isConnected():
    while cam.hasDepthData():
        # This stops the display causing latency.
        frame = cam.getDepthData()

        if frame.frameType() == tof.FrameType.RADIAL:
            # Update radial frames
            rimg.set_data(np.copy(np.asarray(frame)))
            plt.draw()

        del frame

    plt.show(block=False)
    # This makes sure the event loop is updated
    plt.pause(0.1)

cam.disconnect()
